@@ -14,38 +14,67 @@ logger = logging.getLogger()
 
 
 def replace_option(option_type, option_value, event_helper, cache, kodexa_client):
+    """Replace an option based on its type and value.
+
+    Args:
+        option_type (str): The type of the option.
+        option_value (str): The value of the option.
+        event_helper: The event helper object.
+        cache: The cache object.
+        kodexa_client: The Kodexa client object.
+
+    Returns:
+        The replaced option based on its type and value.
+
+    Raises:
+        Exception: If there is an error accessing the document or taxonomy.
+
+    Notes:
+        - If the option type is 'document', the function will download the document from the store and replace the option with it.
+        - If the option type contains the word 'store', the function will return a store object instance.
+        - If the option type contains the word 'pipeline', the function will create a pipeline object instance.
+        - If the option type is 'taxonomy', the function will return a taxonomy object instance.
+        - If the option type is not recognized, the function will return the original option value.
+    """
     logger.info("Replacing option")
-    if option_type == 'document':
+    if option_type == "document":
         # We need to download the document from the store and replace the option with it
 
         full_url = option_value
         logger.info(f"Breaking down the full url for the document {full_url}")
 
-        if '/' in full_url:
-            url_parts = full_url.split(':')
+        if "/" in full_url:
+            url_parts = full_url.split(":")
 
             # Each part, split by "/"
             version = url_parts[1].split("/")[0]
             store_ref = f"{url_parts[0]}:{version}"
             document_family_id = url_parts[1].split("/")[1]
-            logger.info(f"Downloading document parameter {store_ref}/{document_family_id}")
+            logger.info(
+                f"Downloading document parameter {store_ref}/{document_family_id}"
+            )
 
             if store_ref != "" and document_family_id != "undefined":
                 try:
-
                     logger.info(f"Using store {store_ref}")
-                    cache_key = f'store-{store_ref}'
+                    cache_key = f"store-{store_ref}"
 
                     if cache_key not in cache:
                         logger.info(f"Using store {store_ref}")
                         from kodexa.platform.client import DocumentStoreEndpoint
-                        store: DocumentStoreEndpoint = kodexa_client.get_object_by_ref('store', store_ref)
+
+                        store: DocumentStoreEndpoint = kodexa_client.get_object_by_ref(
+                            "store", store_ref
+                        )
                         from kodexa.platform.client import DocumentFamilyEndpoint
-                        document_family: DocumentFamilyEndpoint = store.get_family(document_family_id)
+
+                        document_family: DocumentFamilyEndpoint = store.get_family(
+                            document_family_id
+                        )
                         document = document_family.get_document()
                         document.ref = full_url
                         cache[cache_key] = document
-                        logger.info(f"Downloaded document")
+                        logger.info("Downloaded document")
 
                     # We keep the ref of the document so we can use it later
                     return cache[cache_key]
@@ -54,41 +83,46 @@ def replace_option(option_type, option_value, event_helper, cache, kodexa_client
                     logger.warning(f"Unable to access the document ({e})")
                     return None
             else:
-                logger.info(f"Document reference not available")
+                logger.info("Document reference not available")
                 return None
 
         elif len(full_url) > 0:
             # We have an ID to a Content Object
-            return Document.from_kddb(event_helper.get_content_object(content_object_id=full_url).read())
+            return Document.from_kddb(
+                event_helper.get_content_object(content_object_id=full_url).read()
+            )
 
-    if 'store' in option_type.lower():
+    if "store" in option_type.lower():
         logger.info(f"Getting Store object instance {option_type} as {option_value}")
 
         # We need to create a remote store
-        store = kodexa_client.get_object_by_ref('store', option_value)
+        store = kodexa_client.get_object_by_ref("store", option_value)
         return store
 
-    if 'pipeline' in option_type.lower():
+    if "pipeline" in option_type.lower():
         logger.info(f"Getting pipeline instance {option_type} as {option_value}")
 
         # To create a pipeline to represent the option
         pipeline = Pipeline()
         pipeline.steps = []
 
-        if isinstance(option_value['steps'], list):
-
-            for index, step in enumerate(option_value['steps']):
+        if isinstance(option_value["steps"], list):
+            for index, step in enumerate(option_value["steps"]):
                 logger.info(f"Creating step {step}")
-                pipeline.add_step(step['ref'], name=f'Step {index}', step_type=step['stepType'],
-                                  options=step['options'] if 'options' in step else {})
+                pipeline.add_step(
+                    step["ref"],
+                    name=f"Step {index}",
+                    step_type=step["stepType"],
+                    options=step["options"] if "options" in step else {},
+                )
 
         return pipeline
 
-    if option_type == 'taxonomy':
+    if option_type == "taxonomy":
         logger.info(f"Getting Taxonomy object instance {option_type} as {option_value}")
 
         try:
-            taxonomy = kodexa_client.get_object_by_ref('taxo', option_value)
+            taxonomy = kodexa_client.get_object_by_ref("taxo", option_value)
         except Exception as e:
             logger.warning(f"Unable to access the taxonomy ({e})")
             return None
@@ -99,23 +133,53 @@ def replace_option(option_type, option_value, event_helper, cache, kodexa_client
 
 
 def replace_options(step, event_helper, cache, kodexa_client):
-    logger.info(f"Determine is we have any options that need replacement")
+    """
+    Replaces options in a step with their corresponding values.
+
+    Args:
+        step (Step): The step object containing the options to be replaced.
+        event_helper (EventHelper): The event helper object.
+        cache (Cache): The cache object.
+        kodexa_client (KodexaClient): The Kodexa client object.
+
+    Returns:
+        None
+
+    Raises:
+        None
+
+    Example:
+        replace_options(step, event_helper, cache, kodexa_client)
+    """
+    logger.info("Determine is we have any options that need replacement")
     # We need to document any documents that are part of the options
     for key in step.option_types.keys():
         logger.info(f"Check option type for key {key}")
 
         if key in step.options:
             logger.info(f"Type is {step.option_types[key]}")
-            if step.option_types[key].startswith('list:'):
+            if step.option_types[key].startswith("list:"):
                 result = []
                 logger.info("Is a list type")
                 for value in step.options[key]:
                     result.append(
-                        replace_option(step.option_types[key].split(':')[1], value, event_helper, cache, kodexa_client))
+                        replace_option(
+                            step.option_types[key].split(":")[1],
+                            value,
+                            event_helper,
+                            cache,
+                            kodexa_client,
+                        )
+                    )
                 step.options[key] = result
             else:
-                step.options[key] = replace_option(step.option_types[key], step.options[key], event_helper,
-                                                   cache, kodexa_client)
+                step.options[key] = replace_option(
+                    step.option_types[key],
+                    step.options[key],
+                    event_helper,
+                    cache,
+                    kodexa_client,
+                )
 
 
 class AssistantMetadata:
@@ -123,7 +187,9 @@ class AssistantMetadata:
     A set of metadata for the assistant that can be made available on from the context
     """
 
-    def __init__(self, assistant_id: str, assistant_name: str, project_id: Optional[str] = None):
+    def __init__(
+        self, assistant_id: str, assistant_name: str, project_id: Optional[str] = None
+    ):
         self.assistant_id = assistant_id
         """The ID of the assistant"""
         self.assistant_name = assistant_name
@@ -137,9 +203,15 @@ class AssistantPipeline:
     The wrapper for a pipeline that they assistant will request to be executed
     """
 
-    def __init__(self, pipeline, description=None, write_back_to_store: bool = False,
-                 data_store: Optional[Store] = None,
-                 taxonomies: Optional[List[Taxonomy]] = None, labels_to_apply: Optional[List[str]] = None):
+    def __init__(
+        self,
+        pipeline,
+        description=None,
+        write_back_to_store: bool = False,
+        data_store: Optional[Store] = None,
+        taxonomies: Optional[List[Taxonomy]] = None,
+        labels_to_apply: Optional[List[str]] = None,
+    ):
         self.pipeline = pipeline
         """The pipeline to execute"""
         self.description = description
@@ -172,8 +244,13 @@ class AssistantResponse:
     event.
     """
 
-    def __init__(self, pipelines: List[AssistantPipeline] = None, text: Optional[str] = None,
-                 output_document: Document = None, enabled_logging=False):
+    def __init__(
+        self,
+        pipelines: List[AssistantPipeline] = None,
+        text: Optional[str] = None,
+        output_document: Document = None,
+        enabled_logging=False,
+    ):
         """
         Initialize the response from the assistant
 
@@ -207,8 +284,14 @@ class AssistantContext:
 
     from kodexa.model import ContentEvent
 
-    def __init__(self, metadata: AssistantMetadata, path_to_kodexa_metadata: str = 'kodexa.yml',
-                 stores=None, content_provider=None, extension_pack_util=None):
+    def __init__(
+        self,
+        metadata: AssistantMetadata,
+        path_to_kodexa_metadata: str = "kodexa.yml",
+        stores=None,
+        content_provider=None,
+        extension_pack_util=None,
+    ):
         """
         Initialize the context based with a path to the kodexa file
 
@@ -223,6 +306,7 @@ class AssistantContext:
         if stores is None:
             stores = []
         from kodexa.testing import ExtensionPackUtil
+
         if extension_pack_util is None:
             self.extension_pack_util = ExtensionPackUtil(path_to_kodexa_metadata)
         else:
@@ -283,7 +367,10 @@ class AssistantContext:
 
         if event.document_family.store_ref is not None:
             from kodexa import KodexaClient
-            return KodexaClient().get_object_by_ref('store', event.document_family.store_ref)
+
+            return KodexaClient().get_object_by_ref(
+                "store", event.document_family.store_ref
+            )
 
         raise Exception(f"Unable to get store ref {event.document_family.store_ref}")
 
@@ -293,7 +380,9 @@ class Assistant:
     that is working with set of content
     """
 
-    def process_event(self, event: BaseEvent, context: AssistantContext) -> AssistantResponse:
+    def process_event(
+        self, event: BaseEvent, context: AssistantContext
+    ) -> AssistantResponse:
         """The assistant will need to examine the event to determine if it wants to respond
 
         The event will focus on a specific content object (that will be stored and available).  Based on the
